Module: Aws::LocationService
- Defined in:
- lib/aws-sdk-locationservice/endpoint_parameters.rb,
sig/client.rbs,
sig/errors.rbs,
sig/params.rbs,
sig/waiters.rbs,
sig/resource.rbs,
lib/aws-sdk-locationservice/plugins/endpoints.rb,
lib/aws-sdk-locationservice/endpoint_provider.rb,
lib/aws-sdk-locationservice/client_api.rb,
lib/aws-sdk-locationservice/endpoints.rb,
lib/aws-sdk-locationservice/resource.rb,
lib/aws-sdk-locationservice/waiters.rb,
lib/aws-sdk-locationservice/errors.rb,
lib/aws-sdk-locationservice/client.rb,
lib/aws-sdk-locationservice/types.rb,
lib/aws-sdk-locationservice.rb
Overview
This module provides support for Amazon Location Service. This module is available in the
aws-sdk-locationservice gem.
Client
The Client class provides one method for each API operation. Operation methods each accept a hash of request parameters and return a response structure.
location_service = Aws::LocationService::Client.new
resp = location_service.associate_tracker_consumer(params)
See Client for more information.
Errors
Errors returned from Amazon Location Service are defined in the Errors module and all extend Errors::ServiceError.
begin
# do stuff
rescue Aws::LocationService::Errors::ServiceError
# rescues all Amazon Location Service API errors
end
See Errors for more information.
Defined Under Namespace
Modules: ClientApi, Endpoints, Errors, Params, Plugins, Types, Waiters Classes: Client, EndpointParameters, EndpointProvider, Resource
service collapse
- GEM_VERSION =
'1.90.0'