Class: Aws::LocationService::Types::AppleApp
- Inherits:
-
Struct
- Object
- Struct
- Aws::LocationService::Types::AppleApp
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-locationservice/types.rb
Overview
Unique identifying information for an Apple app (iOS, macOS, tvOS and watchOS). Consists of an Apple Bundle ID.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bundle_id ⇒ String
The unique identifier of the app across all Apple platforms (iOS, macOS, tvOS and watchOS).
Instance Attribute Details
#bundle_id ⇒ String
The unique identifier of the app across all Apple platforms (iOS, macOS, tvOS and watchOS).
Example: ‘com.mydomain.appname`
240 241 242 243 244 |
# File 'lib/aws-sdk-locationservice/types.rb', line 240 class AppleApp < Struct.new( :bundle_id) SENSITIVE = [] include Aws::Structure end |