Class: Aws::LocationService::Types::BatchDeleteGeofenceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LocationService::Types::BatchDeleteGeofenceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-locationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#collection_name ⇒ String
The geofence collection storing the geofences to be deleted.
-
#geofence_ids ⇒ Array<String>
The batch of geofences to be deleted.
Instance Attribute Details
#collection_name ⇒ String
The geofence collection storing the geofences to be deleted.
361 362 363 364 365 366 |
# File 'lib/aws-sdk-locationservice/types.rb', line 361 class BatchDeleteGeofenceRequest < Struct.new( :collection_name, :geofence_ids) SENSITIVE = [] include Aws::Structure end |
#geofence_ids ⇒ Array<String>
The batch of geofences to be deleted.
361 362 363 364 365 366 |
# File 'lib/aws-sdk-locationservice/types.rb', line 361 class BatchDeleteGeofenceRequest < Struct.new( :collection_name, :geofence_ids) SENSITIVE = [] include Aws::Structure end |