Class: Aws::LocationService::Types::CreateKeyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-locationservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:expire_time]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

An optional description for the API key resource.



1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
# File 'lib/aws-sdk-locationservice/types.rb', line 1617

class CreateKeyRequest < Struct.new(
  :key_name,
  :restrictions,
  :description,
  :expire_time,
  :no_expiry,
  :tags)
  SENSITIVE = [:expire_time]
  include Aws::Structure
end

#expire_timeTime

The optional timestamp for when the API key resource will expire in ISO 8601 format: YYYY-MM-DDThh:mm:ss.sssZ. One of NoExpiry or ExpireTime must be set.



1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
# File 'lib/aws-sdk-locationservice/types.rb', line 1617

class CreateKeyRequest < Struct.new(
  :key_name,
  :restrictions,
  :description,
  :expire_time,
  :no_expiry,
  :tags)
  SENSITIVE = [:expire_time]
  include Aws::Structure
end

#key_nameString

A custom name for the API key resource.

Requirements:

  • Contain only alphanumeric characters (A–Z, a–z, 0–9), hyphens (-), periods (.), and underscores (_).

  • Must be a unique API key name.

  • No spaces allowed. For example, ExampleAPIKey.



1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
# File 'lib/aws-sdk-locationservice/types.rb', line 1617

class CreateKeyRequest < Struct.new(
  :key_name,
  :restrictions,
  :description,
  :expire_time,
  :no_expiry,
  :tags)
  SENSITIVE = [:expire_time]
  include Aws::Structure
end

#no_expiryBoolean

Optionally set to true to set no expiration time for the API key. One of NoExpiry or ExpireTime must be set.



1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
# File 'lib/aws-sdk-locationservice/types.rb', line 1617

class CreateKeyRequest < Struct.new(
  :key_name,
  :restrictions,
  :description,
  :expire_time,
  :no_expiry,
  :tags)
  SENSITIVE = [:expire_time]
  include Aws::Structure
end

#restrictionsTypes::ApiKeyRestrictions

The API key restrictions for the API key resource.



1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
# File 'lib/aws-sdk-locationservice/types.rb', line 1617

class CreateKeyRequest < Struct.new(
  :key_name,
  :restrictions,
  :description,
  :expire_time,
  :no_expiry,
  :tags)
  SENSITIVE = [:expire_time]
  include Aws::Structure
end

#tagsHash<String,String>

Applies one or more tags to the map resource. A tag is a key-value pair that helps manage, identify, search, and filter your resources by labelling them.

Format: "key" : "value"

Restrictions:

  • Maximum 50 tags per resource

  • Each resource tag must be unique with a maximum of one value.

  • Maximum key length: 128 Unicode characters in UTF-8

  • Maximum value length: 256 Unicode characters in UTF-8

  • Can use alphanumeric characters (A–Z, a–z, 0–9), and the following characters: + - = . _ : / @.

  • Cannot use "aws:" as a prefix for a key.



1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
# File 'lib/aws-sdk-locationservice/types.rb', line 1617

class CreateKeyRequest < Struct.new(
  :key_name,
  :restrictions,
  :description,
  :expire_time,
  :no_expiry,
  :tags)
  SENSITIVE = [:expire_time]
  include Aws::Structure
end