Class: Aws::LocationService::Types::CreatePlaceIndexRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LocationService::Types::CreatePlaceIndexRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-locationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_source ⇒ String
Specifies the geospatial data provider for the new place index.
-
#data_source_configuration ⇒ Types::DataSourceConfiguration
Specifies the data storage option requesting Places.
-
#description ⇒ String
The optional description for the place index resource.
-
#index_name ⇒ String
The name of the place index resource.
-
#pricing_plan ⇒ String
No longer used.
-
#tags ⇒ Hash<String,String>
Applies one or more tags to the place index resource.
Instance Attribute Details
#data_source ⇒ String
Specifies the geospatial data provider for the new place index.
HERE returns an error.
Valid values include:
-
Esri– For additional information about Esri's coverage in your region of interest, see Esri details on geocoding coverage. -
Grab– Grab provides place index functionality for Southeast Asia. For additional information about GrabMaps' coverage, see GrabMaps countries and areas covered. -
Here– For additional information about HERE Technologies' coverage in your region of interest, see HERE details on goecoding coverage.If you specify HERE Technologies (
Here) as the data provider, you may not store results for locations in Japan. For more information, see the Amazon Web Services service terms for Amazon Location Service.
For additional information , see Data providers on the Amazon Location Service developer guide.
1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 |
# File 'lib/aws-sdk-locationservice/types.rb', line 1860 class CreatePlaceIndexRequest < Struct.new( :index_name, :data_source, :pricing_plan, :description, :data_source_configuration, :tags) SENSITIVE = [] include Aws::Structure end |
#data_source_configuration ⇒ Types::DataSourceConfiguration
Specifies the data storage option requesting Places.
1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 |
# File 'lib/aws-sdk-locationservice/types.rb', line 1860 class CreatePlaceIndexRequest < Struct.new( :index_name, :data_source, :pricing_plan, :description, :data_source_configuration, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The optional description for the place index resource.
1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 |
# File 'lib/aws-sdk-locationservice/types.rb', line 1860 class CreatePlaceIndexRequest < Struct.new( :index_name, :data_source, :pricing_plan, :description, :data_source_configuration, :tags) SENSITIVE = [] include Aws::Structure end |
#index_name ⇒ String
The name of the place index resource.
Requirements:
-
Contain only alphanumeric characters (A–Z, a–z, 0–9), hyphens (-), periods (.), and underscores (_).
-
Must be a unique place index resource name.
-
No spaces allowed. For example,
ExamplePlaceIndex.
1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 |
# File 'lib/aws-sdk-locationservice/types.rb', line 1860 class CreatePlaceIndexRequest < Struct.new( :index_name, :data_source, :pricing_plan, :description, :data_source_configuration, :tags) SENSITIVE = [] include Aws::Structure end |
#pricing_plan ⇒ String
No longer used. If included, the only allowed value is
RequestBasedUsage.
1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 |
# File 'lib/aws-sdk-locationservice/types.rb', line 1860 class CreatePlaceIndexRequest < Struct.new( :index_name, :data_source, :pricing_plan, :description, :data_source_configuration, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Applies one or more tags to the place index resource. A tag is a key-value pair that helps you manage, identify, search, and filter your resources.
Format: "key" : "value"
Restrictions:
-
Maximum 50 tags per resource.
-
Each tag key must be unique and must have exactly one associated value.
-
Maximum key length: 128 Unicode characters in UTF-8.
-
Maximum value length: 256 Unicode characters in UTF-8.
-
Can use alphanumeric characters (A–Z, a–z, 0–9), and the following characters: + - = . _ : / @
-
Cannot use "aws:" as a prefix for a key.
1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 |
# File 'lib/aws-sdk-locationservice/types.rb', line 1860 class CreatePlaceIndexRequest < Struct.new( :index_name, :data_source, :pricing_plan, :description, :data_source_configuration, :tags) SENSITIVE = [] include Aws::Structure end |