Class: Aws::LocationService::Types::CreateRouteCalculatorRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LocationService::Types::CreateRouteCalculatorRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-locationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#calculator_name ⇒ String
The name of the route calculator resource.
-
#data_source ⇒ String
Specifies the data provider of traffic and road network data.
-
#description ⇒ String
The optional description for the route calculator resource.
-
#pricing_plan ⇒ String
No longer used.
-
#tags ⇒ Hash<String,String>
Applies one or more tags to the route calculator resource.
Instance Attribute Details
#calculator_name ⇒ String
The name of the route calculator resource.
Requirements:
-
Can use alphanumeric characters (A–Z, a–z, 0–9) , hyphens (-), periods (.), and underscores (_).
-
Must be a unique Route calculator resource name.
-
No spaces allowed. For example,
ExampleRouteCalculator.
1995 1996 1997 1998 1999 2000 2001 2002 2003 |
# File 'lib/aws-sdk-locationservice/types.rb', line 1995 class CreateRouteCalculatorRequest < Struct.new( :calculator_name, :data_source, :pricing_plan, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#data_source ⇒ String
Specifies the data provider of traffic and road network data.
HERE returns an error.
Valid values include:
-
Esri– For additional information about Esri's coverage in your region of interest, see Esri details on street networks and traffic coverage.Route calculators that use Esri as a data source only calculate routes that are shorter than 400 km.
-
Grab– Grab provides routing functionality for Southeast Asia. For additional information about GrabMaps' coverage, see GrabMaps countries and areas covered. -
Here– For additional information about HERE Technologies' coverage in your region of interest, see HERE car routing coverage and HERE truck routing coverage.
For additional information , see Data providers on the Amazon Location Service Developer Guide.
1995 1996 1997 1998 1999 2000 2001 2002 2003 |
# File 'lib/aws-sdk-locationservice/types.rb', line 1995 class CreateRouteCalculatorRequest < Struct.new( :calculator_name, :data_source, :pricing_plan, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The optional description for the route calculator resource.
1995 1996 1997 1998 1999 2000 2001 2002 2003 |
# File 'lib/aws-sdk-locationservice/types.rb', line 1995 class CreateRouteCalculatorRequest < Struct.new( :calculator_name, :data_source, :pricing_plan, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#pricing_plan ⇒ String
No longer used. If included, the only allowed value is
RequestBasedUsage.
1995 1996 1997 1998 1999 2000 2001 2002 2003 |
# File 'lib/aws-sdk-locationservice/types.rb', line 1995 class CreateRouteCalculatorRequest < Struct.new( :calculator_name, :data_source, :pricing_plan, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Applies one or more tags to the route calculator resource. A tag is a key-value pair helps manage, identify, search, and filter your resources by labelling them.
- For example: {
"tag1" : "value1","tag2" : "value2"}
^
Format: "key" : "value"
Restrictions:
-
Maximum 50 tags per resource
-
Each resource tag must be unique with a maximum of one value.
-
Maximum key length: 128 Unicode characters in UTF-8
-
Maximum value length: 256 Unicode characters in UTF-8
-
Can use alphanumeric characters (A–Z, a–z, 0–9), and the following characters: + - = . _ : / @.
-
Cannot use "aws:" as a prefix for a key.
1995 1996 1997 1998 1999 2000 2001 2002 2003 |
# File 'lib/aws-sdk-locationservice/types.rb', line 1995 class CreateRouteCalculatorRequest < Struct.new( :calculator_name, :data_source, :pricing_plan, :description, :tags) SENSITIVE = [] include Aws::Structure end |