Class: Aws::LocationService::Types::DescribeTrackerResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LocationService::Types::DescribeTrackerResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-locationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:create_time, :update_time]
Instance Attribute Summary collapse
-
#create_time ⇒ Time
The timestamp for when the tracker resource was created in [ ISO 8601] format: ‘YYYY-MM-DDThh:mm:ss.sssZ`.
-
#description ⇒ String
The optional description for the tracker resource.
-
#event_bridge_enabled ⇒ Boolean
Whether ‘UPDATE` events from this tracker in EventBridge are enabled.
-
#kms_key_enable_geospatial_queries ⇒ Boolean
Enables ‘GeospatialQueries` for a tracker that uses a [Amazon Web Services KMS customer managed key].
-
#kms_key_id ⇒ String
A key identifier for an [Amazon Web Services KMS customer managed key] assigned to the Amazon Location resource.
-
#position_filtering ⇒ String
The position filtering method of the tracker resource.
-
#pricing_plan ⇒ String
Always returns ‘RequestBasedUsage`.
-
#pricing_plan_data_source ⇒ String
No longer used.
-
#tags ⇒ Hash<String,String>
The tags associated with the tracker resource.
-
#tracker_arn ⇒ String
The Amazon Resource Name (ARN) for the tracker resource.
-
#tracker_name ⇒ String
The name of the tracker resource.
-
#update_time ⇒ Time
The timestamp for when the tracker resource was last updated in [ ISO 8601] format: ‘YYYY-MM-DDThh:mm:ss.sssZ`.
Instance Attribute Details
#create_time ⇒ Time
The timestamp for when the tracker resource was created in [ ISO 8601] format: ‘YYYY-MM-DDThh:mm:ss.sssZ`.
2927 2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 2942 |
# File 'lib/aws-sdk-locationservice/types.rb', line 2927 class DescribeTrackerResponse < Struct.new( :tracker_name, :tracker_arn, :description, :pricing_plan, :pricing_plan_data_source, :tags, :create_time, :update_time, :kms_key_id, :position_filtering, :event_bridge_enabled, :kms_key_enable_geospatial_queries) SENSITIVE = [:create_time, :update_time] include Aws::Structure end |
#description ⇒ String
The optional description for the tracker resource.
2927 2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 2942 |
# File 'lib/aws-sdk-locationservice/types.rb', line 2927 class DescribeTrackerResponse < Struct.new( :tracker_name, :tracker_arn, :description, :pricing_plan, :pricing_plan_data_source, :tags, :create_time, :update_time, :kms_key_id, :position_filtering, :event_bridge_enabled, :kms_key_enable_geospatial_queries) SENSITIVE = [:create_time, :update_time] include Aws::Structure end |
#event_bridge_enabled ⇒ Boolean
Whether ‘UPDATE` events from this tracker in EventBridge are enabled. If set to `true` these events will be sent to EventBridge.
2927 2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 2942 |
# File 'lib/aws-sdk-locationservice/types.rb', line 2927 class DescribeTrackerResponse < Struct.new( :tracker_name, :tracker_arn, :description, :pricing_plan, :pricing_plan_data_source, :tags, :create_time, :update_time, :kms_key_id, :position_filtering, :event_bridge_enabled, :kms_key_enable_geospatial_queries) SENSITIVE = [:create_time, :update_time] include Aws::Structure end |
#kms_key_enable_geospatial_queries ⇒ Boolean
Enables ‘GeospatialQueries` for a tracker that uses a [Amazon Web Services KMS customer managed key].
This parameter is only used if you are using a KMS customer managed key.
<note markdown=“1”> If you wish to encrypt your data using your own KMS customer managed key, then the Bounding Polygon Queries feature will be disabled by default. This is because by using this feature, a representation of your device positions will not be encrypted using the your KMS managed key. The exact device position, however; is still encrypted using your managed key.
You can choose to opt-in to the Bounding Polygon Quseries feature.
This is done by setting the ‘KmsKeyEnableGeospatialQueries` parameter to true when creating or updating a Tracker.
</note>
[1]: docs.aws.amazon.com/kms/latest/developerguide/create-keys.html
2927 2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 2942 |
# File 'lib/aws-sdk-locationservice/types.rb', line 2927 class DescribeTrackerResponse < Struct.new( :tracker_name, :tracker_arn, :description, :pricing_plan, :pricing_plan_data_source, :tags, :create_time, :update_time, :kms_key_id, :position_filtering, :event_bridge_enabled, :kms_key_enable_geospatial_queries) SENSITIVE = [:create_time, :update_time] include Aws::Structure end |
#kms_key_id ⇒ String
A key identifier for an [Amazon Web Services KMS customer managed key] assigned to the Amazon Location resource.
[1]: docs.aws.amazon.com/kms/latest/developerguide/create-keys.html
2927 2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 2942 |
# File 'lib/aws-sdk-locationservice/types.rb', line 2927 class DescribeTrackerResponse < Struct.new( :tracker_name, :tracker_arn, :description, :pricing_plan, :pricing_plan_data_source, :tags, :create_time, :update_time, :kms_key_id, :position_filtering, :event_bridge_enabled, :kms_key_enable_geospatial_queries) SENSITIVE = [:create_time, :update_time] include Aws::Structure end |
#position_filtering ⇒ String
The position filtering method of the tracker resource.
2927 2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 2942 |
# File 'lib/aws-sdk-locationservice/types.rb', line 2927 class DescribeTrackerResponse < Struct.new( :tracker_name, :tracker_arn, :description, :pricing_plan, :pricing_plan_data_source, :tags, :create_time, :update_time, :kms_key_id, :position_filtering, :event_bridge_enabled, :kms_key_enable_geospatial_queries) SENSITIVE = [:create_time, :update_time] include Aws::Structure end |
#pricing_plan ⇒ String
Always returns ‘RequestBasedUsage`.
2927 2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 2942 |
# File 'lib/aws-sdk-locationservice/types.rb', line 2927 class DescribeTrackerResponse < Struct.new( :tracker_name, :tracker_arn, :description, :pricing_plan, :pricing_plan_data_source, :tags, :create_time, :update_time, :kms_key_id, :position_filtering, :event_bridge_enabled, :kms_key_enable_geospatial_queries) SENSITIVE = [:create_time, :update_time] include Aws::Structure end |
#pricing_plan_data_source ⇒ String
No longer used. Always returns an empty string.
2927 2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 2942 |
# File 'lib/aws-sdk-locationservice/types.rb', line 2927 class DescribeTrackerResponse < Struct.new( :tracker_name, :tracker_arn, :description, :pricing_plan, :pricing_plan_data_source, :tags, :create_time, :update_time, :kms_key_id, :position_filtering, :event_bridge_enabled, :kms_key_enable_geospatial_queries) SENSITIVE = [:create_time, :update_time] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags associated with the tracker resource.
2927 2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 2942 |
# File 'lib/aws-sdk-locationservice/types.rb', line 2927 class DescribeTrackerResponse < Struct.new( :tracker_name, :tracker_arn, :description, :pricing_plan, :pricing_plan_data_source, :tags, :create_time, :update_time, :kms_key_id, :position_filtering, :event_bridge_enabled, :kms_key_enable_geospatial_queries) SENSITIVE = [:create_time, :update_time] include Aws::Structure end |
#tracker_arn ⇒ String
The Amazon Resource Name (ARN) for the tracker resource. Used when you need to specify a resource across all Amazon Web Services.
-
Format example: ‘arn:aws:geo:region:account-id:tracker/ExampleTracker`
^
2927 2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 2942 |
# File 'lib/aws-sdk-locationservice/types.rb', line 2927 class DescribeTrackerResponse < Struct.new( :tracker_name, :tracker_arn, :description, :pricing_plan, :pricing_plan_data_source, :tags, :create_time, :update_time, :kms_key_id, :position_filtering, :event_bridge_enabled, :kms_key_enable_geospatial_queries) SENSITIVE = [:create_time, :update_time] include Aws::Structure end |
#tracker_name ⇒ String
The name of the tracker resource.
2927 2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 2942 |
# File 'lib/aws-sdk-locationservice/types.rb', line 2927 class DescribeTrackerResponse < Struct.new( :tracker_name, :tracker_arn, :description, :pricing_plan, :pricing_plan_data_source, :tags, :create_time, :update_time, :kms_key_id, :position_filtering, :event_bridge_enabled, :kms_key_enable_geospatial_queries) SENSITIVE = [:create_time, :update_time] include Aws::Structure end |
#update_time ⇒ Time
The timestamp for when the tracker resource was last updated in [ ISO 8601] format: ‘YYYY-MM-DDThh:mm:ss.sssZ`.
2927 2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 2942 |
# File 'lib/aws-sdk-locationservice/types.rb', line 2927 class DescribeTrackerResponse < Struct.new( :tracker_name, :tracker_arn, :description, :pricing_plan, :pricing_plan_data_source, :tags, :create_time, :update_time, :kms_key_id, :position_filtering, :event_bridge_enabled, :kms_key_enable_geospatial_queries) SENSITIVE = [:create_time, :update_time] include Aws::Structure end |