Class: Aws::LocationService::Types::ForecastGeofenceEventsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-locationservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#collection_nameString

The name of the geofence collection.

Returns:

  • (String)


3194
3195
3196
3197
3198
3199
3200
3201
3202
3203
3204
# File 'lib/aws-sdk-locationservice/types.rb', line 3194

class ForecastGeofenceEventsRequest < Struct.new(
  :collection_name,
  :device_state,
  :time_horizon_minutes,
  :distance_unit,
  :speed_unit,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#device_stateTypes::ForecastGeofenceEventsDeviceState

Represents the device's state, including its current position and speed. When speed is omitted, this API performs a containment check. The containment check operation returns IDLE events for geofences where the device is currently inside of, but no other events.



3194
3195
3196
3197
3198
3199
3200
3201
3202
3203
3204
# File 'lib/aws-sdk-locationservice/types.rb', line 3194

class ForecastGeofenceEventsRequest < Struct.new(
  :collection_name,
  :device_state,
  :time_horizon_minutes,
  :distance_unit,
  :speed_unit,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#distance_unitString

The distance unit used for the NearestDistance property returned in a forecasted event. The measurement system must match for DistanceUnit and SpeedUnit; if Kilometers is specified for DistanceUnit, then SpeedUnit must be KilometersPerHour.

Default Value: Kilometers

Returns:

  • (String)


3194
3195
3196
3197
3198
3199
3200
3201
3202
3203
3204
# File 'lib/aws-sdk-locationservice/types.rb', line 3194

class ForecastGeofenceEventsRequest < Struct.new(
  :collection_name,
  :device_state,
  :time_horizon_minutes,
  :distance_unit,
  :speed_unit,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

An optional limit for the number of resources returned in a single call.

Default value: 20

Returns:

  • (Integer)


3194
3195
3196
3197
3198
3199
3200
3201
3202
3203
3204
# File 'lib/aws-sdk-locationservice/types.rb', line 3194

class ForecastGeofenceEventsRequest < Struct.new(
  :collection_name,
  :device_state,
  :time_horizon_minutes,
  :distance_unit,
  :speed_unit,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The pagination token specifying which page of results to return in the response. If no token is provided, the default page is the first page.

Default value: null

Returns:

  • (String)


3194
3195
3196
3197
3198
3199
3200
3201
3202
3203
3204
# File 'lib/aws-sdk-locationservice/types.rb', line 3194

class ForecastGeofenceEventsRequest < Struct.new(
  :collection_name,
  :device_state,
  :time_horizon_minutes,
  :distance_unit,
  :speed_unit,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#speed_unitString

The speed unit for the device captured by the device state. The measurement system must match for DistanceUnit and SpeedUnit; if Kilometers is specified for DistanceUnit, then SpeedUnit must be KilometersPerHour.

Default Value: KilometersPerHour.

Returns:

  • (String)


3194
3195
3196
3197
3198
3199
3200
3201
3202
3203
3204
# File 'lib/aws-sdk-locationservice/types.rb', line 3194

class ForecastGeofenceEventsRequest < Struct.new(
  :collection_name,
  :device_state,
  :time_horizon_minutes,
  :distance_unit,
  :speed_unit,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#time_horizon_minutesFloat

The forward-looking time window for forecasting, specified in minutes. The API only returns events that are predicted to occur within this time horizon. When no value is specified, this API performs a containment check. The containment check operation returns IDLE events for geofences where the device is currently inside of, but no other events.

Returns:

  • (Float)


3194
3195
3196
3197
3198
3199
3200
3201
3202
3203
3204
# File 'lib/aws-sdk-locationservice/types.rb', line 3194

class ForecastGeofenceEventsRequest < Struct.new(
  :collection_name,
  :device_state,
  :time_horizon_minutes,
  :distance_unit,
  :speed_unit,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end