Class: Aws::LocationService::Types::ForecastGeofenceEventsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LocationService::Types::ForecastGeofenceEventsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-locationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#distance_unit ⇒ String
The distance unit for the forecasted events.
-
#forecasted_events ⇒ Array<Types::ForecastedEvent>
The list of forecasted events.
-
#next_token ⇒ String
The pagination token specifying which page of results to return in the response.
-
#speed_unit ⇒ String
The speed unit for the forecasted events.
Instance Attribute Details
#distance_unit ⇒ String
The distance unit for the forecasted events.
3226 3227 3228 3229 3230 3231 3232 3233 |
# File 'lib/aws-sdk-locationservice/types.rb', line 3226 class ForecastGeofenceEventsResponse < Struct.new( :forecasted_events, :next_token, :distance_unit, :speed_unit) SENSITIVE = [] include Aws::Structure end |
#forecasted_events ⇒ Array<Types::ForecastedEvent>
The list of forecasted events.
3226 3227 3228 3229 3230 3231 3232 3233 |
# File 'lib/aws-sdk-locationservice/types.rb', line 3226 class ForecastGeofenceEventsResponse < Struct.new( :forecasted_events, :next_token, :distance_unit, :speed_unit) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token specifying which page of results to return in the response. If no token is provided, the default page is the first page.
3226 3227 3228 3229 3230 3231 3232 3233 |
# File 'lib/aws-sdk-locationservice/types.rb', line 3226 class ForecastGeofenceEventsResponse < Struct.new( :forecasted_events, :next_token, :distance_unit, :speed_unit) SENSITIVE = [] include Aws::Structure end |
#speed_unit ⇒ String
The speed unit for the forecasted events.
3226 3227 3228 3229 3230 3231 3232 3233 |
# File 'lib/aws-sdk-locationservice/types.rb', line 3226 class ForecastGeofenceEventsResponse < Struct.new( :forecasted_events, :next_token, :distance_unit, :speed_unit) SENSITIVE = [] include Aws::Structure end |