Class: Aws::LocationService::Types::GetDevicePositionHistoryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-locationservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:start_time_inclusive, :end_time_exclusive]

Instance Attribute Summary collapse

Instance Attribute Details

#device_idString

The device whose position history you want to retrieve.

Returns:

  • (String)


3493
3494
3495
3496
3497
3498
3499
3500
3501
3502
# File 'lib/aws-sdk-locationservice/types.rb', line 3493

class GetDevicePositionHistoryRequest < Struct.new(
  :tracker_name,
  :device_id,
  :next_token,
  :start_time_inclusive,
  :end_time_exclusive,
  :max_results)
  SENSITIVE = [:start_time_inclusive, :end_time_exclusive]
  include Aws::Structure
end

#end_time_exclusiveTime

Specify the end time for the position history in ISO 8601 format: YYYY-MM-DDThh:mm:ss.sssZ. By default, the value will be the time that the request is made.

Requirement:

  • The time specified for EndTimeExclusive must be after the time for StartTimeInclusive.

^

Returns:

  • (Time)


3493
3494
3495
3496
3497
3498
3499
3500
3501
3502
# File 'lib/aws-sdk-locationservice/types.rb', line 3493

class GetDevicePositionHistoryRequest < Struct.new(
  :tracker_name,
  :device_id,
  :next_token,
  :start_time_inclusive,
  :end_time_exclusive,
  :max_results)
  SENSITIVE = [:start_time_inclusive, :end_time_exclusive]
  include Aws::Structure
end

#max_resultsInteger

An optional limit for the number of device positions returned in a single call.

Default value: 100

Returns:

  • (Integer)


3493
3494
3495
3496
3497
3498
3499
3500
3501
3502
# File 'lib/aws-sdk-locationservice/types.rb', line 3493

class GetDevicePositionHistoryRequest < Struct.new(
  :tracker_name,
  :device_id,
  :next_token,
  :start_time_inclusive,
  :end_time_exclusive,
  :max_results)
  SENSITIVE = [:start_time_inclusive, :end_time_exclusive]
  include Aws::Structure
end

#next_tokenString

The pagination token specifying which page of results to return in the response. If no token is provided, the default page is the first page.

Default value: null

Returns:

  • (String)


3493
3494
3495
3496
3497
3498
3499
3500
3501
3502
# File 'lib/aws-sdk-locationservice/types.rb', line 3493

class GetDevicePositionHistoryRequest < Struct.new(
  :tracker_name,
  :device_id,
  :next_token,
  :start_time_inclusive,
  :end_time_exclusive,
  :max_results)
  SENSITIVE = [:start_time_inclusive, :end_time_exclusive]
  include Aws::Structure
end

#start_time_inclusiveTime

Specify the start time for the position history in ISO 8601 format: YYYY-MM-DDThh:mm:ss.sssZ. By default, the value will be 24 hours prior to the time that the request is made.

Requirement:

  • The time specified for StartTimeInclusive must be before EndTimeExclusive.

^

Returns:

  • (Time)


3493
3494
3495
3496
3497
3498
3499
3500
3501
3502
# File 'lib/aws-sdk-locationservice/types.rb', line 3493

class GetDevicePositionHistoryRequest < Struct.new(
  :tracker_name,
  :device_id,
  :next_token,
  :start_time_inclusive,
  :end_time_exclusive,
  :max_results)
  SENSITIVE = [:start_time_inclusive, :end_time_exclusive]
  include Aws::Structure
end

#tracker_nameString

The tracker resource receiving the request for the device position history.

Returns:

  • (String)


3493
3494
3495
3496
3497
3498
3499
3500
3501
3502
# File 'lib/aws-sdk-locationservice/types.rb', line 3493

class GetDevicePositionHistoryRequest < Struct.new(
  :tracker_name,
  :device_id,
  :next_token,
  :start_time_inclusive,
  :end_time_exclusive,
  :max_results)
  SENSITIVE = [:start_time_inclusive, :end_time_exclusive]
  include Aws::Structure
end