Class: Aws::LocationService::Types::GetJobResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-locationservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:created_at, :ended_at, :updated_at]

Instance Attribute Summary collapse

Instance Attribute Details

#actionString

Action performed by the job.

Returns:

  • (String)


3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
# File 'lib/aws-sdk-locationservice/types.rb', line 3752

class GetJobResponse < Struct.new(
  :action,
  :action_options,
  :created_at,
  :ended_at,
  :error,
  :execution_role_arn,
  :input_options,
  :job_arn,
  :job_id,
  :name,
  :output_options,
  :status,
  :updated_at,
  :tags)
  SENSITIVE = [:created_at, :ended_at, :updated_at]
  include Aws::Structure
end

#action_optionsTypes::JobActionOptions

Additional options for configuring job action parameters.



3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
# File 'lib/aws-sdk-locationservice/types.rb', line 3752

class GetJobResponse < Struct.new(
  :action,
  :action_options,
  :created_at,
  :ended_at,
  :error,
  :execution_role_arn,
  :input_options,
  :job_arn,
  :job_id,
  :name,
  :output_options,
  :status,
  :updated_at,
  :tags)
  SENSITIVE = [:created_at, :ended_at, :updated_at]
  include Aws::Structure
end

#created_atTime

Job creation time in [ISO 8601] format: ‘YYYY-MM-DDThh:mm:ss.sss`.

[1]: www.iso.org/iso-8601-date-and-time-format.html

Returns:

  • (Time)


3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
# File 'lib/aws-sdk-locationservice/types.rb', line 3752

class GetJobResponse < Struct.new(
  :action,
  :action_options,
  :created_at,
  :ended_at,
  :error,
  :execution_role_arn,
  :input_options,
  :job_arn,
  :job_id,
  :name,
  :output_options,
  :status,
  :updated_at,
  :tags)
  SENSITIVE = [:created_at, :ended_at, :updated_at]
  include Aws::Structure
end

#ended_atTime

Job completion time in [ISO 8601] format: ‘YYYY-MM-DDThh:mm:ss.sss`. Only returned for jobs in a terminal status: `Completed` | `Failed` | `Cancelled`.

[1]: www.iso.org/iso-8601-date-and-time-format.html

Returns:

  • (Time)


3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
# File 'lib/aws-sdk-locationservice/types.rb', line 3752

class GetJobResponse < Struct.new(
  :action,
  :action_options,
  :created_at,
  :ended_at,
  :error,
  :execution_role_arn,
  :input_options,
  :job_arn,
  :job_id,
  :name,
  :output_options,
  :status,
  :updated_at,
  :tags)
  SENSITIVE = [:created_at, :ended_at, :updated_at]
  include Aws::Structure
end

#errorTypes::JobError

Error information if the job failed.

Returns:



3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
# File 'lib/aws-sdk-locationservice/types.rb', line 3752

class GetJobResponse < Struct.new(
  :action,
  :action_options,
  :created_at,
  :ended_at,
  :error,
  :execution_role_arn,
  :input_options,
  :job_arn,
  :job_id,
  :name,
  :output_options,
  :status,
  :updated_at,
  :tags)
  SENSITIVE = [:created_at, :ended_at, :updated_at]
  include Aws::Structure
end

#execution_role_arnString

IAM role used for permissions when running the job.

Returns:

  • (String)


3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
# File 'lib/aws-sdk-locationservice/types.rb', line 3752

class GetJobResponse < Struct.new(
  :action,
  :action_options,
  :created_at,
  :ended_at,
  :error,
  :execution_role_arn,
  :input_options,
  :job_arn,
  :job_id,
  :name,
  :output_options,
  :status,
  :updated_at,
  :tags)
  SENSITIVE = [:created_at, :ended_at, :updated_at]
  include Aws::Structure
end

#input_optionsTypes::JobInputOptions

Input configuration.



3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
# File 'lib/aws-sdk-locationservice/types.rb', line 3752

class GetJobResponse < Struct.new(
  :action,
  :action_options,
  :created_at,
  :ended_at,
  :error,
  :execution_role_arn,
  :input_options,
  :job_arn,
  :job_id,
  :name,
  :output_options,
  :status,
  :updated_at,
  :tags)
  SENSITIVE = [:created_at, :ended_at, :updated_at]
  include Aws::Structure
end

#job_arnString

Amazon Resource Name (ARN) of the specified job.

Returns:

  • (String)


3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
# File 'lib/aws-sdk-locationservice/types.rb', line 3752

class GetJobResponse < Struct.new(
  :action,
  :action_options,
  :created_at,
  :ended_at,
  :error,
  :execution_role_arn,
  :input_options,
  :job_arn,
  :job_id,
  :name,
  :output_options,
  :status,
  :updated_at,
  :tags)
  SENSITIVE = [:created_at, :ended_at, :updated_at]
  include Aws::Structure
end

#job_idString

Unique job identifier.

Returns:

  • (String)


3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
# File 'lib/aws-sdk-locationservice/types.rb', line 3752

class GetJobResponse < Struct.new(
  :action,
  :action_options,
  :created_at,
  :ended_at,
  :error,
  :execution_role_arn,
  :input_options,
  :job_arn,
  :job_id,
  :name,
  :output_options,
  :status,
  :updated_at,
  :tags)
  SENSITIVE = [:created_at, :ended_at, :updated_at]
  include Aws::Structure
end

#nameString

Job name (if provided during creation).

Returns:

  • (String)


3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
# File 'lib/aws-sdk-locationservice/types.rb', line 3752

class GetJobResponse < Struct.new(
  :action,
  :action_options,
  :created_at,
  :ended_at,
  :error,
  :execution_role_arn,
  :input_options,
  :job_arn,
  :job_id,
  :name,
  :output_options,
  :status,
  :updated_at,
  :tags)
  SENSITIVE = [:created_at, :ended_at, :updated_at]
  include Aws::Structure
end

#output_optionsTypes::JobOutputOptions

Output configuration.



3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
# File 'lib/aws-sdk-locationservice/types.rb', line 3752

class GetJobResponse < Struct.new(
  :action,
  :action_options,
  :created_at,
  :ended_at,
  :error,
  :execution_role_arn,
  :input_options,
  :job_arn,
  :job_id,
  :name,
  :output_options,
  :status,
  :updated_at,
  :tags)
  SENSITIVE = [:created_at, :ended_at, :updated_at]
  include Aws::Structure
end

#statusString

Current job status.

Returns:

  • (String)


3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
# File 'lib/aws-sdk-locationservice/types.rb', line 3752

class GetJobResponse < Struct.new(
  :action,
  :action_options,
  :created_at,
  :ended_at,
  :error,
  :execution_role_arn,
  :input_options,
  :job_arn,
  :job_id,
  :name,
  :output_options,
  :status,
  :updated_at,
  :tags)
  SENSITIVE = [:created_at, :ended_at, :updated_at]
  include Aws::Structure
end

#tagsHash<String,String>

Tags and corresponding values associated with the specified job.

Returns:

  • (Hash<String,String>)


3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
# File 'lib/aws-sdk-locationservice/types.rb', line 3752

class GetJobResponse < Struct.new(
  :action,
  :action_options,
  :created_at,
  :ended_at,
  :error,
  :execution_role_arn,
  :input_options,
  :job_arn,
  :job_id,
  :name,
  :output_options,
  :status,
  :updated_at,
  :tags)
  SENSITIVE = [:created_at, :ended_at, :updated_at]
  include Aws::Structure
end

#updated_atTime

Last update time in [ISO 8601] format: ‘YYYY-MM-DDThh:mm:ss.sss`.

[1]: www.iso.org/iso-8601-date-and-time-format.html

Returns:

  • (Time)


3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
# File 'lib/aws-sdk-locationservice/types.rb', line 3752

class GetJobResponse < Struct.new(
  :action,
  :action_options,
  :created_at,
  :ended_at,
  :error,
  :execution_role_arn,
  :input_options,
  :job_arn,
  :job_id,
  :name,
  :output_options,
  :status,
  :updated_at,
  :tags)
  SENSITIVE = [:created_at, :ended_at, :updated_at]
  include Aws::Structure
end