Class: Aws::LocationService::Types::GetPlaceResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LocationService::Types::GetPlaceResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-locationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#place ⇒ Types::Place
Details about the result, such as its address and position.
Instance Attribute Details
#place ⇒ Types::Place
Details about the result, such as its address and position.
4118 4119 4120 4121 4122 |
# File 'lib/aws-sdk-locationservice/types.rb', line 4118 class GetPlaceResponse < Struct.new( :place) SENSITIVE = [] include Aws::Structure end |