Class: Aws::LocationService::Types::JobError
- Inherits:
-
Struct
- Object
- Struct
- Aws::LocationService::Types::JobError
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-locationservice/types.rb
Overview
Error information for failed jobs.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code ⇒ String
Error code indicating the type of error that occurred.
-
#messages ⇒ Array<String>
Error messages providing details about the failure.
Instance Attribute Details
#code ⇒ String
Error code indicating the type of error that occurred.
4196 4197 4198 4199 4200 4201 |
# File 'lib/aws-sdk-locationservice/types.rb', line 4196 class JobError < Struct.new( :code, :messages) SENSITIVE = [] include Aws::Structure end |
#messages ⇒ Array<String>
Error messages providing details about the failure.
4196 4197 4198 4199 4200 4201 |
# File 'lib/aws-sdk-locationservice/types.rb', line 4196 class JobError < Struct.new( :code, :messages) SENSITIVE = [] include Aws::Structure end |