Class: Aws::LocationService::Types::JobOutputOptions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-locationservice/types.rb

Overview

Configuration for output data location and format.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#formatString

Output data format. Currently only “Parquet” is supported.

Returns:

  • (String)


4254
4255
4256
4257
4258
4259
# File 'lib/aws-sdk-locationservice/types.rb', line 4254

class JobOutputOptions < Struct.new(
  :format,
  :location)
  SENSITIVE = []
  include Aws::Structure
end

#locationString

S3 ARN or URI where output files will be written.

<note markdown=“1”> The Amazon S3 bucket must exist in the same Amazon Web Services region where you plan to run your job.

</note>

Returns:

  • (String)


4254
4255
4256
4257
4258
4259
# File 'lib/aws-sdk-locationservice/types.rb', line 4254

class JobOutputOptions < Struct.new(
  :format,
  :location)
  SENSITIVE = []
  include Aws::Structure
end