Class: Aws::LocationService::Types::ListJobsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-locationservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filterTypes::JobsFilter

An optional structure containing criteria by which to filter job results.

Returns:



4717
4718
4719
4720
4721
4722
4723
# File 'lib/aws-sdk-locationservice/types.rb', line 4717

class ListJobsRequest < Struct.new(
  :filter,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

Maximum number of jobs to return.

Returns:

  • (Integer)


4717
4718
4719
4720
4721
4722
4723
# File 'lib/aws-sdk-locationservice/types.rb', line 4717

class ListJobsRequest < Struct.new(
  :filter,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The pagination token specifying which page of results to return in the response. If no token is provided, the default page is the first page.

Returns:

  • (String)


4717
4718
4719
4720
4721
4722
4723
# File 'lib/aws-sdk-locationservice/types.rb', line 4717

class ListJobsRequest < Struct.new(
  :filter,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end