Class: Aws::LocationService::Types::ListJobsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LocationService::Types::ListJobsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-locationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#entries ⇒ Array<Types::ListJobsResponseEntry>
List of jobs in your Amazon Web Services account.
-
#next_token ⇒ String
Token for retrieving the next page (present if more results available).
Instance Attribute Details
#entries ⇒ Array<Types::ListJobsResponseEntry>
List of jobs in your Amazon Web Services account.
4736 4737 4738 4739 4740 4741 |
# File 'lib/aws-sdk-locationservice/types.rb', line 4736 class ListJobsResponse < Struct.new( :entries, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Token for retrieving the next page (present if more results available).
4736 4737 4738 4739 4740 4741 |
# File 'lib/aws-sdk-locationservice/types.rb', line 4736 class ListJobsResponse < Struct.new( :entries, :next_token) SENSITIVE = [] include Aws::Structure end |