Class: Aws::LocationService::Types::ListKeysRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-locationservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filterTypes::ApiKeyFilter

Optionally filter the list to only Active or Expired API keys.

Returns:



4853
4854
4855
4856
4857
4858
4859
# File 'lib/aws-sdk-locationservice/types.rb', line 4853

class ListKeysRequest < Struct.new(
  :max_results,
  :next_token,
  :filter)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

An optional limit for the number of resources returned in a single call.

Default value: 100

Returns:

  • (Integer)


4853
4854
4855
4856
4857
4858
4859
# File 'lib/aws-sdk-locationservice/types.rb', line 4853

class ListKeysRequest < Struct.new(
  :max_results,
  :next_token,
  :filter)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The pagination token specifying which page of results to return in the response. If no token is provided, the default page is the first page.

Default value: null

Returns:

  • (String)


4853
4854
4855
4856
4857
4858
4859
# File 'lib/aws-sdk-locationservice/types.rb', line 4853

class ListKeysRequest < Struct.new(
  :max_results,
  :next_token,
  :filter)
  SENSITIVE = []
  include Aws::Structure
end