Class: Aws::LocationService::Types::ListKeysResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LocationService::Types::ListKeysResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-locationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#entries ⇒ Array<Types::ListKeysResponseEntry>
Contains API key resources in your Amazon Web Services account.
-
#next_token ⇒ String
A pagination token indicating there are additional pages available.
Instance Attribute Details
#entries ⇒ Array<Types::ListKeysResponseEntry>
Contains API key resources in your Amazon Web Services account. Details include API key name, allowed referers and timestamp for when the API key will expire.
4875 4876 4877 4878 4879 4880 |
# File 'lib/aws-sdk-locationservice/types.rb', line 4875 class ListKeysResponse < Struct.new( :entries, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A pagination token indicating there are additional pages available. You can use the token in a following request to fetch the next set of results.
4875 4876 4877 4878 4879 4880 |
# File 'lib/aws-sdk-locationservice/types.rb', line 4875 class ListKeysResponse < Struct.new( :entries, :next_token) SENSITIVE = [] include Aws::Structure end |