Class: Aws::LocationService::Types::ListPlaceIndexesResponseEntry
- Inherits:
-
Struct
- Object
- Struct
- Aws::LocationService::Types::ListPlaceIndexesResponseEntry
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-locationservice/types.rb
Overview
A place index resource listed in your Amazon Web Services account.
Constant Summary collapse
- SENSITIVE =
[:create_time, :update_time]
Instance Attribute Summary collapse
-
#create_time ⇒ Time
The timestamp for when the place index resource was created in [ISO 8601][1] format:
YYYY-MM-DDThh:mm:ss.sssZ. -
#data_source ⇒ String
The data provider of geospatial data.
-
#description ⇒ String
The optional description for the place index resource.
-
#index_name ⇒ String
The name of the place index resource.
-
#pricing_plan ⇒ String
No longer used.
-
#update_time ⇒ Time
The timestamp for when the place index resource was last updated in [ISO 8601][1] format:
YYYY-MM-DDThh:mm:ss.sssZ.
Instance Attribute Details
#create_time ⇒ Time
The timestamp for when the place index resource was created in ISO
8601 format: YYYY-MM-DDThh:mm:ss.sssZ.
5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 |
# File 'lib/aws-sdk-locationservice/types.rb', line 5126 class ListPlaceIndexesResponseEntry < Struct.new( :index_name, :description, :data_source, :pricing_plan, :create_time, :update_time) SENSITIVE = [:create_time, :update_time] include Aws::Structure end |
#data_source ⇒ String
The data provider of geospatial data. Values can be one of the following:
-
Esri -
Grab -
Here
For more information about data providers, see Amazon Location Service data providers.
5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 |
# File 'lib/aws-sdk-locationservice/types.rb', line 5126 class ListPlaceIndexesResponseEntry < Struct.new( :index_name, :description, :data_source, :pricing_plan, :create_time, :update_time) SENSITIVE = [:create_time, :update_time] include Aws::Structure end |
#description ⇒ String
The optional description for the place index resource.
5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 |
# File 'lib/aws-sdk-locationservice/types.rb', line 5126 class ListPlaceIndexesResponseEntry < Struct.new( :index_name, :description, :data_source, :pricing_plan, :create_time, :update_time) SENSITIVE = [:create_time, :update_time] include Aws::Structure end |
#index_name ⇒ String
The name of the place index resource.
5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 |
# File 'lib/aws-sdk-locationservice/types.rb', line 5126 class ListPlaceIndexesResponseEntry < Struct.new( :index_name, :description, :data_source, :pricing_plan, :create_time, :update_time) SENSITIVE = [:create_time, :update_time] include Aws::Structure end |
#pricing_plan ⇒ String
No longer used. Always returns RequestBasedUsage.
5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 |
# File 'lib/aws-sdk-locationservice/types.rb', line 5126 class ListPlaceIndexesResponseEntry < Struct.new( :index_name, :description, :data_source, :pricing_plan, :create_time, :update_time) SENSITIVE = [:create_time, :update_time] include Aws::Structure end |
#update_time ⇒ Time
The timestamp for when the place index resource was last updated in
ISO 8601 format: YYYY-MM-DDThh:mm:ss.sssZ.
5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 |
# File 'lib/aws-sdk-locationservice/types.rb', line 5126 class ListPlaceIndexesResponseEntry < Struct.new( :index_name, :description, :data_source, :pricing_plan, :create_time, :update_time) SENSITIVE = [:create_time, :update_time] include Aws::Structure end |