Class: Aws::LocationService::Types::ListTrackerConsumersRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-locationservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

An optional limit for the number of resources returned in a single call.

Default value: 100

Returns:

  • (Integer)


5309
5310
5311
5312
5313
5314
5315
# File 'lib/aws-sdk-locationservice/types.rb', line 5309

class ListTrackerConsumersRequest < Struct.new(
  :tracker_name,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The pagination token specifying which page of results to return in the response. If no token is provided, the default page is the first page.

Default value: null

Returns:

  • (String)


5309
5310
5311
5312
5313
5314
5315
# File 'lib/aws-sdk-locationservice/types.rb', line 5309

class ListTrackerConsumersRequest < Struct.new(
  :tracker_name,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#tracker_nameString

The tracker resource whose associated geofence collections you want to list.

Returns:

  • (String)


5309
5310
5311
5312
5313
5314
5315
# File 'lib/aws-sdk-locationservice/types.rb', line 5309

class ListTrackerConsumersRequest < Struct.new(
  :tracker_name,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end