Class: Aws::LocationService::Types::SearchForPositionResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-locationservice/types.rb

Overview

Contains a search result from a position search query that is run on a place index resource.

Constant Summary collapse

SENSITIVE =
[:distance, :place_id]

Instance Attribute Summary collapse

Instance Attribute Details

#distanceFloat

The distance in meters of a great-circle arc between the query position and the result.

A great-circle arc is the shortest path on a sphere, in this case the Earth. This returns the shortest distance between two locations.

Returns:

  • (Float)


6131
6132
6133
6134
6135
6136
6137
# File 'lib/aws-sdk-locationservice/types.rb', line 6131

class SearchForPositionResult < Struct.new(
  :place,
  :distance,
  :place_id)
  SENSITIVE = [:distance, :place_id]
  include Aws::Structure
end

#placeTypes::Place

Details about the search result, such as its address and position.

Returns:



6131
6132
6133
6134
6135
6136
6137
# File 'lib/aws-sdk-locationservice/types.rb', line 6131

class SearchForPositionResult < Struct.new(
  :place,
  :distance,
  :place_id)
  SENSITIVE = [:distance, :place_id]
  include Aws::Structure
end

#place_idString

The unique identifier of the place. You can use this with the GetPlace operation to find the place again later.

For SearchPlaceIndexForPosition operations, the PlaceId is returned only by place indexes that use HERE or Grab as a data provider.

Returns:

  • (String)


6131
6132
6133
6134
6135
6136
6137
# File 'lib/aws-sdk-locationservice/types.rb', line 6131

class SearchForPositionResult < Struct.new(
  :place,
  :distance,
  :place_id)
  SENSITIVE = [:distance, :place_id]
  include Aws::Structure
end