Class: Aws::LocationService::Types::SearchPlaceIndexForTextSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-locationservice/types.rb

Overview

A summary of the request sent by using SearchPlaceIndexForText.

Constant Summary collapse

SENSITIVE =
[:text, :bias_position, :filter_b_box, :filter_countries, :result_b_box, :filter_categories]

Instance Attribute Summary collapse

Instance Attribute Details

#bias_positionArray<Float>

Contains the coordinates for the optional bias position specified in the request.

This parameter contains a pair of numbers. The first number represents the X coordinate, or longitude; the second number represents the Y coordinate, or latitude.

For example, [-123.1174, 49.2847] represents the position with longitude -123.1174 and latitude 49.2847.



6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
6847
6848
6849
# File 'lib/aws-sdk-locationservice/types.rb', line 6837

class SearchPlaceIndexForTextSummary < Struct.new(
  :text,
  :bias_position,
  :filter_b_box,
  :filter_countries,
  :max_results,
  :result_b_box,
  :data_source,
  :language,
  :filter_categories)
  SENSITIVE = [:text, :bias_position, :filter_b_box, :filter_countries, :result_b_box, :filter_categories]
  include Aws::Structure
end

#data_sourceString

The geospatial data provider attached to the place index resource specified in the request. Values can be one of the following:

  • Esri

  • Grab

  • Here

For more information about data providers, see Amazon Location Service data providers.



6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
6847
6848
6849
# File 'lib/aws-sdk-locationservice/types.rb', line 6837

class SearchPlaceIndexForTextSummary < Struct.new(
  :text,
  :bias_position,
  :filter_b_box,
  :filter_countries,
  :max_results,
  :result_b_box,
  :data_source,
  :language,
  :filter_categories)
  SENSITIVE = [:text, :bias_position, :filter_b_box, :filter_countries, :result_b_box, :filter_categories]
  include Aws::Structure
end

#filter_b_boxArray<Float>

Contains the coordinates for the optional bounding box specified in the request.



6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
6847
6848
6849
# File 'lib/aws-sdk-locationservice/types.rb', line 6837

class SearchPlaceIndexForTextSummary < Struct.new(
  :text,
  :bias_position,
  :filter_b_box,
  :filter_countries,
  :max_results,
  :result_b_box,
  :data_source,
  :language,
  :filter_categories)
  SENSITIVE = [:text, :bias_position, :filter_b_box, :filter_countries, :result_b_box, :filter_categories]
  include Aws::Structure
end

#filter_categoriesArray<String>

The optional category filter specified in the request.



6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
6847
6848
6849
# File 'lib/aws-sdk-locationservice/types.rb', line 6837

class SearchPlaceIndexForTextSummary < Struct.new(
  :text,
  :bias_position,
  :filter_b_box,
  :filter_countries,
  :max_results,
  :result_b_box,
  :data_source,
  :language,
  :filter_categories)
  SENSITIVE = [:text, :bias_position, :filter_b_box, :filter_countries, :result_b_box, :filter_categories]
  include Aws::Structure
end

#filter_countriesArray<String>

Contains the optional country filter specified in the request.



6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
6847
6848
6849
# File 'lib/aws-sdk-locationservice/types.rb', line 6837

class SearchPlaceIndexForTextSummary < Struct.new(
  :text,
  :bias_position,
  :filter_b_box,
  :filter_countries,
  :max_results,
  :result_b_box,
  :data_source,
  :language,
  :filter_categories)
  SENSITIVE = [:text, :bias_position, :filter_b_box, :filter_countries, :result_b_box, :filter_categories]
  include Aws::Structure
end

#languageString

The preferred language used to return results. Matches the language in the request. The value is a valid BCP 47 language tag, for example, en for English.



6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
6847
6848
6849
# File 'lib/aws-sdk-locationservice/types.rb', line 6837

class SearchPlaceIndexForTextSummary < Struct.new(
  :text,
  :bias_position,
  :filter_b_box,
  :filter_countries,
  :max_results,
  :result_b_box,
  :data_source,
  :language,
  :filter_categories)
  SENSITIVE = [:text, :bias_position, :filter_b_box, :filter_countries, :result_b_box, :filter_categories]
  include Aws::Structure
end

#max_resultsInteger

Contains the optional result count limit specified in the request.



6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
6847
6848
6849
# File 'lib/aws-sdk-locationservice/types.rb', line 6837

class SearchPlaceIndexForTextSummary < Struct.new(
  :text,
  :bias_position,
  :filter_b_box,
  :filter_countries,
  :max_results,
  :result_b_box,
  :data_source,
  :language,
  :filter_categories)
  SENSITIVE = [:text, :bias_position, :filter_b_box, :filter_countries, :result_b_box, :filter_categories]
  include Aws::Structure
end

#result_b_boxArray<Float>

The bounding box that fully contains all search results.

If you specified the optional FilterBBox parameter in the request, ResultBBox is contained within FilterBBox.



6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
6847
6848
6849
# File 'lib/aws-sdk-locationservice/types.rb', line 6837

class SearchPlaceIndexForTextSummary < Struct.new(
  :text,
  :bias_position,
  :filter_b_box,
  :filter_countries,
  :max_results,
  :result_b_box,
  :data_source,
  :language,
  :filter_categories)
  SENSITIVE = [:text, :bias_position, :filter_b_box, :filter_countries, :result_b_box, :filter_categories]
  include Aws::Structure
end

#textString

The search text specified in the request.



6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
6847
6848
6849
# File 'lib/aws-sdk-locationservice/types.rb', line 6837

class SearchPlaceIndexForTextSummary < Struct.new(
  :text,
  :bias_position,
  :filter_b_box,
  :filter_countries,
  :max_results,
  :result_b_box,
  :data_source,
  :language,
  :filter_categories)
  SENSITIVE = [:text, :bias_position, :filter_b_box, :filter_countries, :result_b_box, :filter_categories]
  include Aws::Structure
end