Class: Aws::LocationService::Types::TruckDimensions
- Inherits:
-
Struct
- Object
- Struct
- Aws::LocationService::Types::TruckDimensions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-locationservice/types.rb
Overview
Contains details about the truck dimensions in the unit of measurement that you specify. Used to filter out roads that can’t support or allow the specified dimensions for requests that specify ‘TravelMode` as `Truck`.
Constant Summary collapse
- SENSITIVE =
[:length, :height, :width]
Instance Attribute Summary collapse
-
#height ⇒ Float
The height of the truck.
-
#length ⇒ Float
The length of the truck.
-
#unit ⇒ String
Specifies the unit of measurement for the truck dimensions.
-
#width ⇒ Float
The width of the truck.
Instance Attribute Details
#height ⇒ Float
The height of the truck.
-
For example, ‘4.5`.
^
<note markdown=“1”> For routes calculated with a HERE resource, this value must be between 0 and 50 meters.
</note>
7176 7177 7178 7179 7180 7181 7182 7183 |
# File 'lib/aws-sdk-locationservice/types.rb', line 7176 class TruckDimensions < Struct.new( :length, :height, :width, :unit) SENSITIVE = [:length, :height, :width] include Aws::Structure end |
#length ⇒ Float
The length of the truck.
-
For example, ‘15.5`.
^
<note markdown=“1”> For routes calculated with a HERE resource, this value must be between 0 and 300 meters.
</note>
7176 7177 7178 7179 7180 7181 7182 7183 |
# File 'lib/aws-sdk-locationservice/types.rb', line 7176 class TruckDimensions < Struct.new( :length, :height, :width, :unit) SENSITIVE = [:length, :height, :width] include Aws::Structure end |
#unit ⇒ String
Specifies the unit of measurement for the truck dimensions.
Default Value: ‘Meters`
7176 7177 7178 7179 7180 7181 7182 7183 |
# File 'lib/aws-sdk-locationservice/types.rb', line 7176 class TruckDimensions < Struct.new( :length, :height, :width, :unit) SENSITIVE = [:length, :height, :width] include Aws::Structure end |
#width ⇒ Float
The width of the truck.
-
For example, ‘4.5`.
^
<note markdown=“1”> For routes calculated with a HERE resource, this value must be between 0 and 50 meters.
</note>
7176 7177 7178 7179 7180 7181 7182 7183 |
# File 'lib/aws-sdk-locationservice/types.rb', line 7176 class TruckDimensions < Struct.new( :length, :height, :width, :unit) SENSITIVE = [:length, :height, :width] include Aws::Structure end |