Class: Aws::LocationService::Types::UpdateMapRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LocationService::Types::UpdateMapRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-locationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration_update ⇒ Types::MapConfigurationUpdate
Updates the parts of the map configuration that can be updated, including the political view.
-
#description ⇒ String
Updates the description for the map resource.
-
#map_name ⇒ String
The name of the map resource to update.
-
#pricing_plan ⇒ String
No longer used.
Instance Attribute Details
#configuration_update ⇒ Types::MapConfigurationUpdate
Updates the parts of the map configuration that can be updated, including the political view.
7403 7404 7405 7406 7407 7408 7409 7410 |
# File 'lib/aws-sdk-locationservice/types.rb', line 7403 class UpdateMapRequest < Struct.new( :map_name, :pricing_plan, :description, :configuration_update) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
Updates the description for the map resource.
7403 7404 7405 7406 7407 7408 7409 7410 |
# File 'lib/aws-sdk-locationservice/types.rb', line 7403 class UpdateMapRequest < Struct.new( :map_name, :pricing_plan, :description, :configuration_update) SENSITIVE = [] include Aws::Structure end |
#map_name ⇒ String
The name of the map resource to update.
7403 7404 7405 7406 7407 7408 7409 7410 |
# File 'lib/aws-sdk-locationservice/types.rb', line 7403 class UpdateMapRequest < Struct.new( :map_name, :pricing_plan, :description, :configuration_update) SENSITIVE = [] include Aws::Structure end |
#pricing_plan ⇒ String
No longer used. If included, the only allowed value is ‘RequestBasedUsage`.
7403 7404 7405 7406 7407 7408 7409 7410 |
# File 'lib/aws-sdk-locationservice/types.rb', line 7403 class UpdateMapRequest < Struct.new( :map_name, :pricing_plan, :description, :configuration_update) SENSITIVE = [] include Aws::Structure end |