Class: Aws::LocationService::Types::ValidateAddressActionOptions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-locationservice/types.rb

Overview

Options specific to address validation jobs.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_featuresArray<String>

A list of optional additional parameters that can be requested for each result.

Values:

  • ‘Position` - Return the position coordinates of the address if available.

  • ‘CountrySpecificAttributes` - Return additional information about the address specific to the country of origin.

Returns:

  • (Array<String>)


7694
7695
7696
7697
7698
# File 'lib/aws-sdk-locationservice/types.rb', line 7694

class ValidateAddressActionOptions < Struct.new(
  :additional_features)
  SENSITIVE = []
  include Aws::Structure
end