Class: Aws::LocationService::Waiters::JobCompleted
- Inherits:
-
Object
- Object
- Aws::LocationService::Waiters::JobCompleted
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-locationservice/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ JobCompleted
constructor
A new instance of JobCompleted.
-
#wait(params = {}) ⇒ Types::GetJobResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ JobCompleted
Returns a new instance of JobCompleted.
84 85 |
# File 'lib/aws-sdk-locationservice/waiters.rb', line 84
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
122 123 124 |
# File 'lib/aws-sdk-locationservice/waiters.rb', line 122 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetJobResponse
Returns a response object which responds to the following methods:
- #action => String
- #action_options => Types::JobActionOptions
- #created_at => Time
- #ended_at => Time
- #error => Types::JobError
- #execution_role_arn => String
- #input_options => Types::JobInputOptions
- #job_arn => String
- #job_id => String
- #name => String
- #output_options => Types::JobOutputOptions
- #status => String
- #updated_at => Time
- #tags => Hash<String,String>
117 |
# File 'lib/aws-sdk-locationservice/waiters.rb', line 117
def wait: (
|