Class: Aws::LocationService::Types::GetJobResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LocationService::Types::GetJobResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-locationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:created_at, :ended_at, :updated_at]
Instance Attribute Summary collapse
-
#action ⇒ String
Action performed by the job.
-
#action_options ⇒ Types::JobActionOptions
Additional options for configuring job action parameters.
-
#created_at ⇒ Time
Job creation time in [ISO 8601] format: ‘YYYY-MM-DDThh:mm:ss.sss`.
-
#ended_at ⇒ Time
Job completion time in [ISO 8601] format: ‘YYYY-MM-DDThh:mm:ss.sss`.
-
#error ⇒ Types::JobError
Error information if the job failed.
-
#execution_role_arn ⇒ String
IAM role used for permissions when running the job.
-
#input_options ⇒ Types::JobInputOptions
Input configuration.
-
#job_arn ⇒ String
Amazon Resource Name (ARN) of the specified job.
-
#job_id ⇒ String
Unique job identifier.
-
#name ⇒ String
Job name (if provided during creation).
-
#output_options ⇒ Types::JobOutputOptions
Output configuration.
-
#status ⇒ String
Current job status.
-
#tags ⇒ Hash<String,String>
Tags and corresponding values associated with the specified job.
-
#updated_at ⇒ Time
Last update time in [ISO 8601] format: ‘YYYY-MM-DDThh:mm:ss.sss`.
Instance Attribute Details
#action ⇒ String
Action performed by the job.
3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 3766 3767 3768 3769 |
# File 'lib/aws-sdk-locationservice/types.rb', line 3752 class GetJobResponse < Struct.new( :action, :action_options, :created_at, :ended_at, :error, :execution_role_arn, :input_options, :job_arn, :job_id, :name, :output_options, :status, :updated_at, :tags) SENSITIVE = [:created_at, :ended_at, :updated_at] include Aws::Structure end |
#action_options ⇒ Types::JobActionOptions
Additional options for configuring job action parameters.
3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 3766 3767 3768 3769 |
# File 'lib/aws-sdk-locationservice/types.rb', line 3752 class GetJobResponse < Struct.new( :action, :action_options, :created_at, :ended_at, :error, :execution_role_arn, :input_options, :job_arn, :job_id, :name, :output_options, :status, :updated_at, :tags) SENSITIVE = [:created_at, :ended_at, :updated_at] include Aws::Structure end |
#created_at ⇒ Time
Job creation time in [ISO 8601] format: ‘YYYY-MM-DDThh:mm:ss.sss`.
3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 3766 3767 3768 3769 |
# File 'lib/aws-sdk-locationservice/types.rb', line 3752 class GetJobResponse < Struct.new( :action, :action_options, :created_at, :ended_at, :error, :execution_role_arn, :input_options, :job_arn, :job_id, :name, :output_options, :status, :updated_at, :tags) SENSITIVE = [:created_at, :ended_at, :updated_at] include Aws::Structure end |
#ended_at ⇒ Time
Job completion time in [ISO 8601] format: ‘YYYY-MM-DDThh:mm:ss.sss`. Only returned for jobs in a terminal status: `Completed` | `Failed` | `Cancelled`.
3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 3766 3767 3768 3769 |
# File 'lib/aws-sdk-locationservice/types.rb', line 3752 class GetJobResponse < Struct.new( :action, :action_options, :created_at, :ended_at, :error, :execution_role_arn, :input_options, :job_arn, :job_id, :name, :output_options, :status, :updated_at, :tags) SENSITIVE = [:created_at, :ended_at, :updated_at] include Aws::Structure end |
#error ⇒ Types::JobError
Error information if the job failed.
3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 3766 3767 3768 3769 |
# File 'lib/aws-sdk-locationservice/types.rb', line 3752 class GetJobResponse < Struct.new( :action, :action_options, :created_at, :ended_at, :error, :execution_role_arn, :input_options, :job_arn, :job_id, :name, :output_options, :status, :updated_at, :tags) SENSITIVE = [:created_at, :ended_at, :updated_at] include Aws::Structure end |
#execution_role_arn ⇒ String
IAM role used for permissions when running the job.
3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 3766 3767 3768 3769 |
# File 'lib/aws-sdk-locationservice/types.rb', line 3752 class GetJobResponse < Struct.new( :action, :action_options, :created_at, :ended_at, :error, :execution_role_arn, :input_options, :job_arn, :job_id, :name, :output_options, :status, :updated_at, :tags) SENSITIVE = [:created_at, :ended_at, :updated_at] include Aws::Structure end |
#input_options ⇒ Types::JobInputOptions
Input configuration.
3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 3766 3767 3768 3769 |
# File 'lib/aws-sdk-locationservice/types.rb', line 3752 class GetJobResponse < Struct.new( :action, :action_options, :created_at, :ended_at, :error, :execution_role_arn, :input_options, :job_arn, :job_id, :name, :output_options, :status, :updated_at, :tags) SENSITIVE = [:created_at, :ended_at, :updated_at] include Aws::Structure end |
#job_arn ⇒ String
Amazon Resource Name (ARN) of the specified job.
3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 3766 3767 3768 3769 |
# File 'lib/aws-sdk-locationservice/types.rb', line 3752 class GetJobResponse < Struct.new( :action, :action_options, :created_at, :ended_at, :error, :execution_role_arn, :input_options, :job_arn, :job_id, :name, :output_options, :status, :updated_at, :tags) SENSITIVE = [:created_at, :ended_at, :updated_at] include Aws::Structure end |
#job_id ⇒ String
Unique job identifier.
3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 3766 3767 3768 3769 |
# File 'lib/aws-sdk-locationservice/types.rb', line 3752 class GetJobResponse < Struct.new( :action, :action_options, :created_at, :ended_at, :error, :execution_role_arn, :input_options, :job_arn, :job_id, :name, :output_options, :status, :updated_at, :tags) SENSITIVE = [:created_at, :ended_at, :updated_at] include Aws::Structure end |
#name ⇒ String
Job name (if provided during creation).
3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 3766 3767 3768 3769 |
# File 'lib/aws-sdk-locationservice/types.rb', line 3752 class GetJobResponse < Struct.new( :action, :action_options, :created_at, :ended_at, :error, :execution_role_arn, :input_options, :job_arn, :job_id, :name, :output_options, :status, :updated_at, :tags) SENSITIVE = [:created_at, :ended_at, :updated_at] include Aws::Structure end |
#output_options ⇒ Types::JobOutputOptions
Output configuration.
3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 3766 3767 3768 3769 |
# File 'lib/aws-sdk-locationservice/types.rb', line 3752 class GetJobResponse < Struct.new( :action, :action_options, :created_at, :ended_at, :error, :execution_role_arn, :input_options, :job_arn, :job_id, :name, :output_options, :status, :updated_at, :tags) SENSITIVE = [:created_at, :ended_at, :updated_at] include Aws::Structure end |
#status ⇒ String
Current job status.
3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 3766 3767 3768 3769 |
# File 'lib/aws-sdk-locationservice/types.rb', line 3752 class GetJobResponse < Struct.new( :action, :action_options, :created_at, :ended_at, :error, :execution_role_arn, :input_options, :job_arn, :job_id, :name, :output_options, :status, :updated_at, :tags) SENSITIVE = [:created_at, :ended_at, :updated_at] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Tags and corresponding values associated with the specified job.
3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 3766 3767 3768 3769 |
# File 'lib/aws-sdk-locationservice/types.rb', line 3752 class GetJobResponse < Struct.new( :action, :action_options, :created_at, :ended_at, :error, :execution_role_arn, :input_options, :job_arn, :job_id, :name, :output_options, :status, :updated_at, :tags) SENSITIVE = [:created_at, :ended_at, :updated_at] include Aws::Structure end |
#updated_at ⇒ Time
Last update time in [ISO 8601] format: ‘YYYY-MM-DDThh:mm:ss.sss`.
3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 3766 3767 3768 3769 |
# File 'lib/aws-sdk-locationservice/types.rb', line 3752 class GetJobResponse < Struct.new( :action, :action_options, :created_at, :ended_at, :error, :execution_role_arn, :input_options, :job_arn, :job_id, :name, :output_options, :status, :updated_at, :tags) SENSITIVE = [:created_at, :ended_at, :updated_at] include Aws::Structure end |