Class: Aws::LocationService::Types::JobInputOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::LocationService::Types::JobInputOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-locationservice/types.rb
Overview
Configuration for input data location and format.
<note markdown=“1”> Input files have a limitation of 10gb per file, and 1gb per Parquet row-group within the file.
</note>
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#format ⇒ String
Input data format.
-
#location ⇒ String
S3 ARN or URI where input files are stored.
Instance Attribute Details
#format ⇒ String
Input data format. Currently only ‘Parquet` is supported.
<note markdown=“1”> Input files have a limitation of 10gb per file, and 1gb per Parquet row-group within the file.
</note>
4230 4231 4232 4233 4234 4235 |
# File 'lib/aws-sdk-locationservice/types.rb', line 4230 class JobInputOptions < Struct.new( :location, :format) SENSITIVE = [] include Aws::Structure end |
#location ⇒ String
S3 ARN or URI where input files are stored.
<note markdown=“1”> The Amazon S3 bucket must be created in the same Amazon Web Services region where you plan to run your job.
</note>
4230 4231 4232 4233 4234 4235 |
# File 'lib/aws-sdk-locationservice/types.rb', line 4230 class JobInputOptions < Struct.new( :location, :format) SENSITIVE = [] include Aws::Structure end |