Class: Aws::LocationService::Types::ListJobsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LocationService::Types::ListJobsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-locationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filter ⇒ Types::JobsFilter
An optional structure containing criteria by which to filter job results.
-
#max_results ⇒ Integer
Maximum number of jobs to return.
-
#next_token ⇒ String
The pagination token specifying which page of results to return in the response.
Instance Attribute Details
#filter ⇒ Types::JobsFilter
An optional structure containing criteria by which to filter job results.
4717 4718 4719 4720 4721 4722 4723 |
# File 'lib/aws-sdk-locationservice/types.rb', line 4717 class ListJobsRequest < Struct.new( :filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
Maximum number of jobs to return.
4717 4718 4719 4720 4721 4722 4723 |
# File 'lib/aws-sdk-locationservice/types.rb', line 4717 class ListJobsRequest < Struct.new( :filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token specifying which page of results to return in the response. If no token is provided, the default page is the first page.
4717 4718 4719 4720 4721 4722 4723 |
# File 'lib/aws-sdk-locationservice/types.rb', line 4717 class ListJobsRequest < Struct.new( :filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |