Class: Aws::LocationService::Types::ListKeysRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LocationService::Types::ListKeysRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-locationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filter ⇒ Types::ApiKeyFilter
Optionally filter the list to only
ActiveorExpiredAPI keys. -
#max_results ⇒ Integer
An optional limit for the number of resources returned in a single call.
-
#next_token ⇒ String
The pagination token specifying which page of results to return in the response.
Instance Attribute Details
#filter ⇒ Types::ApiKeyFilter
Optionally filter the list to only Active or Expired API keys.
4853 4854 4855 4856 4857 4858 4859 |
# File 'lib/aws-sdk-locationservice/types.rb', line 4853 class ListKeysRequest < Struct.new( :max_results, :next_token, :filter) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
An optional limit for the number of resources returned in a single call.
Default value: 100
4853 4854 4855 4856 4857 4858 4859 |
# File 'lib/aws-sdk-locationservice/types.rb', line 4853 class ListKeysRequest < Struct.new( :max_results, :next_token, :filter) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token specifying which page of results to return in the response. If no token is provided, the default page is the first page.
Default value: null
4853 4854 4855 4856 4857 4858 4859 |
# File 'lib/aws-sdk-locationservice/types.rb', line 4853 class ListKeysRequest < Struct.new( :max_results, :next_token, :filter) SENSITIVE = [] include Aws::Structure end |