Class: Aws::LocationService::Types::ListTrackersResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LocationService::Types::ListTrackersResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-locationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#entries ⇒ Array<Types::ListTrackersResponseEntry>
Contains tracker resources in your Amazon Web Services account.
-
#next_token ⇒ String
A pagination token indicating there are additional pages available.
Instance Attribute Details
#entries ⇒ Array<Types::ListTrackersResponseEntry>
Contains tracker resources in your Amazon Web Services account. Details include tracker name, description and timestamps for when the tracker was created and last updated.
5375 5376 5377 5378 5379 5380 |
# File 'lib/aws-sdk-locationservice/types.rb', line 5375 class ListTrackersResponse < Struct.new( :entries, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A pagination token indicating there are additional pages available. You can use the token in a following request to fetch the next set of results.
5375 5376 5377 5378 5379 5380 |
# File 'lib/aws-sdk-locationservice/types.rb', line 5375 class ListTrackersResponse < Struct.new( :entries, :next_token) SENSITIVE = [] include Aws::Structure end |