Class: Aws::LocationService::Types::SearchForPositionResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::LocationService::Types::SearchForPositionResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-locationservice/types.rb
Overview
Contains a search result from a position search query that is run on a place index resource.
Constant Summary collapse
- SENSITIVE =
[:distance, :place_id]
Instance Attribute Summary collapse
-
#distance ⇒ Float
The distance in meters of a great-circle arc between the query position and the result.
-
#place ⇒ Types::Place
Details about the search result, such as its address and position.
-
#place_id ⇒ String
The unique identifier of the place.
Instance Attribute Details
#distance ⇒ Float
The distance in meters of a great-circle arc between the query position and the result.
6131 6132 6133 6134 6135 6136 6137 |
# File 'lib/aws-sdk-locationservice/types.rb', line 6131 class SearchForPositionResult < Struct.new( :place, :distance, :place_id) SENSITIVE = [:distance, :place_id] include Aws::Structure end |
#place ⇒ Types::Place
Details about the search result, such as its address and position.
6131 6132 6133 6134 6135 6136 6137 |
# File 'lib/aws-sdk-locationservice/types.rb', line 6131 class SearchForPositionResult < Struct.new( :place, :distance, :place_id) SENSITIVE = [:distance, :place_id] include Aws::Structure end |
#place_id ⇒ String
The unique identifier of the place. You can use this with the
GetPlace operation to find the place again later.
SearchPlaceIndexForPosition operations, the PlaceId is
returned only by place indexes that use HERE or Grab as a data
provider.
6131 6132 6133 6134 6135 6136 6137 |
# File 'lib/aws-sdk-locationservice/types.rb', line 6131 class SearchForPositionResult < Struct.new( :place, :distance, :place_id) SENSITIVE = [:distance, :place_id] include Aws::Structure end |