Class: Aws::LocationService::Types::SearchPlaceIndexForTextResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LocationService::Types::SearchPlaceIndexForTextResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-locationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#results ⇒ Array<Types::SearchForTextResult>
A list of Places matching the input text.
-
#summary ⇒ Types::SearchPlaceIndexForTextSummary
Contains a summary of the request.
Instance Attribute Details
#results ⇒ Array<Types::SearchForTextResult>
A list of Places matching the input text. Each result contains additional information about the specific point of interest.
Not all response properties are included with all responses. Some properties may only be returned by specific data partners.
6756 6757 6758 6759 6760 6761 |
# File 'lib/aws-sdk-locationservice/types.rb', line 6756 class SearchPlaceIndexForTextResponse < Struct.new( :summary, :results) SENSITIVE = [] include Aws::Structure end |
#summary ⇒ Types::SearchPlaceIndexForTextSummary
Contains a summary of the request. Echoes the input values for ‘BiasPosition`, `FilterBBox`, `FilterCountries`, `Language`, `MaxResults`, and `Text`. Also includes the `DataSource` of the place index and the bounding box, `ResultBBox`, which surrounds the search results.
6756 6757 6758 6759 6760 6761 |
# File 'lib/aws-sdk-locationservice/types.rb', line 6756 class SearchPlaceIndexForTextResponse < Struct.new( :summary, :results) SENSITIVE = [] include Aws::Structure end |