Class: Aws::LocationService::Types::StartJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LocationService::Types::StartJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-locationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
The action to perform on the input data.
-
#action_options ⇒ Types::JobActionOptions
Additional parameters that can be requested for each result.
-
#client_token ⇒ String
A unique identifier for this request to ensure idempotency.
-
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that Amazon Location Service assumes during job processing.
-
#input_options ⇒ Types::JobInputOptions
Configuration for input data location and format.
-
#name ⇒ String
An optional name for the job resource.
-
#output_options ⇒ Types::JobOutputOptions
Configuration for output data location and format.
-
#tags ⇒ Hash<String,String>
Tags and corresponding values to be associated with the job.
Instance Attribute Details
#action ⇒ String
The action to perform on the input data.
6929 6930 6931 6932 6933 6934 6935 6936 6937 6938 6939 6940 |
# File 'lib/aws-sdk-locationservice/types.rb', line 6929 class StartJobRequest < Struct.new( :client_token, :action, :action_options, :execution_role_arn, :input_options, :name, :output_options, :tags) SENSITIVE = [] include Aws::Structure end |
#action_options ⇒ Types::JobActionOptions
Additional parameters that can be requested for each result.
6929 6930 6931 6932 6933 6934 6935 6936 6937 6938 6939 6940 |
# File 'lib/aws-sdk-locationservice/types.rb', line 6929 class StartJobRequest < Struct.new( :client_token, :action, :action_options, :execution_role_arn, :input_options, :name, :output_options, :tags) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique identifier for this request to ensure idempotency.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
6929 6930 6931 6932 6933 6934 6935 6936 6937 6938 6939 6940 |
# File 'lib/aws-sdk-locationservice/types.rb', line 6929 class StartJobRequest < Struct.new( :client_token, :action, :action_options, :execution_role_arn, :input_options, :name, :output_options, :tags) SENSITIVE = [] include Aws::Structure end |
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that Amazon Location Service assumes during job processing. Amazon Location Service uses this role to access the input and output locations specified for the job.
<note markdown=“1”> The IAM role must be created in the same Amazon Web Services account where you plan to run your job.
</note>
For more information about configuring IAM roles for Amazon Location jobs, see [Configure IAM permissions] in the *Amazon Location Service Developer Guide*.
[1]: docs.aws.amazon.com/location/latest/developerguide/configure-iam-role-policy-credentials.html
6929 6930 6931 6932 6933 6934 6935 6936 6937 6938 6939 6940 |
# File 'lib/aws-sdk-locationservice/types.rb', line 6929 class StartJobRequest < Struct.new( :client_token, :action, :action_options, :execution_role_arn, :input_options, :name, :output_options, :tags) SENSITIVE = [] include Aws::Structure end |
#input_options ⇒ Types::JobInputOptions
Configuration for input data location and format.
<note markdown=“1”> Input files have a limitation of 10gb per file, and 1gb per Parquet row-group within the file.
</note>
6929 6930 6931 6932 6933 6934 6935 6936 6937 6938 6939 6940 |
# File 'lib/aws-sdk-locationservice/types.rb', line 6929 class StartJobRequest < Struct.new( :client_token, :action, :action_options, :execution_role_arn, :input_options, :name, :output_options, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
An optional name for the job resource.
6929 6930 6931 6932 6933 6934 6935 6936 6937 6938 6939 6940 |
# File 'lib/aws-sdk-locationservice/types.rb', line 6929 class StartJobRequest < Struct.new( :client_token, :action, :action_options, :execution_role_arn, :input_options, :name, :output_options, :tags) SENSITIVE = [] include Aws::Structure end |
#output_options ⇒ Types::JobOutputOptions
Configuration for output data location and format.
6929 6930 6931 6932 6933 6934 6935 6936 6937 6938 6939 6940 |
# File 'lib/aws-sdk-locationservice/types.rb', line 6929 class StartJobRequest < Struct.new( :client_token, :action, :action_options, :execution_role_arn, :input_options, :name, :output_options, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Tags and corresponding values to be associated with the job.
6929 6930 6931 6932 6933 6934 6935 6936 6937 6938 6939 6940 |
# File 'lib/aws-sdk-locationservice/types.rb', line 6929 class StartJobRequest < Struct.new( :client_token, :action, :action_options, :execution_role_arn, :input_options, :name, :output_options, :tags) SENSITIVE = [] include Aws::Structure end |