Class: Aws::LocationService::Types::ValidateAddressActionOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::LocationService::Types::ValidateAddressActionOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-locationservice/types.rb
Overview
Options specific to address validation jobs.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_features ⇒ Array<String>
A list of optional additional parameters that can be requested for each result.
Instance Attribute Details
#additional_features ⇒ Array<String>
A list of optional additional parameters that can be requested for each result.
Values:
-
‘Position` - Return the position coordinates of the address if available.
-
‘CountrySpecificAttributes` - Return additional information about the address specific to the country of origin.
7694 7695 7696 7697 7698 |
# File 'lib/aws-sdk-locationservice/types.rb', line 7694 class ValidateAddressActionOptions < Struct.new( :additional_features) SENSITIVE = [] include Aws::Structure end |